aboutsummaryrefslogtreecommitdiff
path: root/ef-maris-light-theme.el
diff options
context:
space:
mode:
authorProtesilaos Stavrou <info@protesilaos.com>2023-08-09 08:41:13 +0300
committerProtesilaos Stavrou <info@protesilaos.com>2023-08-09 08:41:13 +0300
commit260dfff2e4ea5d83e1871b3b4768beeb14b66a3b (patch)
treee7b73e84eb13c427c1caa95776518a101f756edc /ef-maris-light-theme.el
parentaf281a72b15044b13bfec10c245605431df52d0b (diff)
ef-maris-{dark,light}: reword one-line theme description
Diffstat (limited to 'ef-maris-light-theme.el')
-rw-r--r--ef-maris-light-theme.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/ef-maris-light-theme.el b/ef-maris-light-theme.el
index 2be4237..ec72f86 100644
--- a/ef-maris-light-theme.el
+++ b/ef-maris-light-theme.el
@@ -1,4 +1,4 @@
;;; ef-maris-light-theme.el --- Legible light theme with blue, cyan, and teal colors -*- lexical-binding:t -*-
;; Copyright (C) 2023 Free Software Foundation, Inc.
@@ -38,7 +38,7 @@
(require 'ef-themes)
(deftheme ef-maris-light
- "Legible light theme with blue, cyan, and teal colors.")
+ "Legible light theme with blue, cyan, and green colors.")
(defconst ef-maris-light-palette
'(
@@ -1,4 +1,4 @@
-;;; ef-maris-light-theme.el --- Legible light theme with blue, cyan, and teal colors -*- lexical-binding:t -*-
+;;; ef-maris-light-theme.el --- Legible light theme with blue, cyan, and green colors -*- lexical-binding:t -*-
;; Copyright (C) 2023 Free Software Foundation, Inc.